==> blotoutfluttersdk-0.0.4.tar.gz: ios/Classes/SwiftBlotoutfluttersdkPlugin.swift <==
import Flutter
import UIKit

public class SwiftBlotoutfluttersdkPlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "blotoutfluttersdk", binaryMessenger: registrar.messenger())
        let instance = SwiftBlotoutfluttersdkPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        switch call.method {
        case MethodName.Initialize_SDK.rawValue:
            self.initializeAnalyticsEngine(call: call, result: result)
            break;
        case MethodName.Update_Blotout_SDK.rawValue:
            self.updateAnalyticsEngineTest(call: call, result:result)
            break;
        case MethodName.Start_Timed_Event.rawValue:
            self.startTimedEvent(call: call, result:result)
            break;
        case MethodName.End_Timed_Event.rawValue:
            self.endTimedEvent(call: call, result:result);
            break;
        case MethodName.Log_Event.rawValue:
            self.logEvent(call: call, result:result)
            break;
        case MethodName.Log_Event_With_Time.rawValue:
            self.logEventWithTime(call: call, result:result)
            break;
        case MethodName.Log_PII_Event.rawValue:
            self.logPIIEvent(call: call, result:result)
            break;
        case MethodName.Log_PHI_Event.rawValue:
            self.logPHIEvent(call: call, result:result)
            break;
        case MethodName.Set_SDK_End_Point_Url.rawValue:
            self.setSDKEndPoint(call: call, result: result)
            break;
        case MethodName.Set_SDK_Enabled.rawValue:
            self.setSDKEnabled(call: call, result: result)
            break;
        case MethodName.Set_Network_Sync_Enabled.rawValue:
            self.setNetworkSyncEnabled(call: call, result: result)
            break;
        case MethodName.Set_Funnel_Events_Enabled.rawValue:
            self.setFunnelEventsEnabled(call: call, result: result)
            break;
        case MethodName.Set_Segment_Events_Enabled.rawValue:
            self.setSegmentEventsEnabled(call: call, result: result)
            break;
        case MethodName.Set_Data_Collection_Enabled.rawValue:
            self.setDataCollectionEnabled(call: call, result: result)
            break;
        case MethodName.Set_System_Events_Enabled.rawValue:
            self.setSystemEventsEnabled(call: call, result: result)
            break;
        case MethodName.Set_Paying_User.rawValue:
            self.setPayingUser(call: call, result: result)
            break;
        case MethodName.Set_Developer_Events_Enabled.rawValue:
            self.setDeveloperEventsEnabled(call: call, result: result)
            break;
        case MethodName.Set_Retention_Events_Enabled.rawValue:
            self.setRetentionEventsEnabled(call: call, result: result)
            break;
            
        case MethodName.IS_Device_Compromised.rawValue:
            self.isDeviceCompromised(call: call, result: result)
            break;
            
        case MethodName.IS_App_Compromised.rawValue:
            self.isAppCompromised(call: call, result: result)
            break;
            
        case MethodName.IS_Simulator.rawValue:
            self.isSimulator(call: call, result: result)
            break;
            
        case MethodName.IS_Environment_Secure.rawValue:
            self.isEnvironmentSecure(call: call, result: result)
            break;
            
        case MethodName.IS_Network_Proxied.rawValue:
            self.setRetentionEventsEnabled(call: call, result: result)
            break;
            
        case MethodName.IS_Running_On_VM.rawValue:
            self.isRunningOnVM(call: call, result: result)
            break;
            
        default:
            break;
        }
    }
}


extension SwiftBlotoutfluttersdkPlugin {
    
    enum MethodName: String, CaseIterable {
        case Initialize_SDK = "initBlotoutSDK"
        case Update_Blotout_SDK = "updateBlotoutSDK"
        case Start_Timed_Event = "startTimedEvent"
        case End_Timed_Event = "endTimedEvent"
        case Log_Event = "logEvent"
        case Log_Event_With_Time = "logEventWithTime"
        case Log_User_Retention_Event = "logUserRetentionEvent"
        case Log_PII_Event = "logPIIEvent"
        case Log_PHI_Event = "logPHIEvent"
        
        case Set_SDK_End_Point_Url = "setSDKEndPointUrl"
        case Set_SDK_Enabled = "setSDKEnabled"
        case Set_Network_Sync_Enabled = "setNetworkSyncEnabled"
        case Set_Data_Collection_Enabled = "setDataCollectionEnabled"
        case Set_Funnel_Events_Enabled = "setFunnelEventsEnabled"
        case Set_Segment_Events_Enabled = "setSegmentEventsEnabled"
        case Set_System_Events_Enabled = "setSystemEventsEnabled"
        case Set_Developer_Events_Enabled = "setDeveloperEventsEnabled"
        case Set_Paying_User = "setPayingUser"
        case Set_Retention_Events_Enabled = "setRetentionEventsEnabled"
        
        case IS_Device_Compromised = "isDeviceCompromised"
        case IS_App_Compromised = "isAppCompromised"
        case IS_Network_Proxied = "isNetworkProxied"
        case IS_Simulator = "isSimulator"
        case IS_Running_On_VM = "isRunningOnVM"
        case IS_Environment_Secure = "isEnvironmentSecure"
    }
}

extension SwiftBlotoutfluttersdkPlugin {
    
    private func initializeAnalyticsEngine(call: FlutterMethodCall, result: @escaping FlutterResult){
        
        if let arguments = call.arguments as? [String:Any] {
            
            if let token = arguments["prodKey"] as? String {
                
                BlotoutAnalytics.sharedInstance()?.initializeAnalyticsEngine(usingTest: token, andProduction: token, inProductionMode: false, withCompletionHandler: { (success, error) in
                    if(success) {
                        return result(true)
                    } else {
                        return result(false)
                    }
                })
            }
        }
    }
    
    
    /*
     * @param blotoutTestKey stage key as String
     * @param blotoutProductionKey production key as String
     */
    private func updateAnalyticsEngineTest(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let token = arguments["prodKey"] as? String {
                BlotoutAnalytics.sharedInstance()?.updateEngineTest(token, andProduction: token);
            }
        }
        
    }
    
    /*
     * @param eventName name of the event
     * @param startEventInfo properties in key/value pair
     */
    private func startTimedEvent(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            
            BlotoutAnalytics.sharedInstance()?.startTimedEvent(eventName!, withInformation: properties)
        }
    }
    
    /*
     * @param eventName name of the event
     * @param endEventInfo properties in key/value pair
     */
    private func endTimedEvent(call: FlutterMethodCall, result: @escaping FlutterResult){
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            
            BlotoutAnalytics.sharedInstance()?.endTimedEvent(eventName!, withInformation: properties)
        }
    }
    
    /*
     * @param eventName name of the event
     * @param eventInfo properties in key/value pair
     */
    private func logEvent(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            
            BlotoutAnalytics.sharedInstance()?.logEvent(eventName!, withInformation: properties)
        }
    }
    
    /*
     * @param eventName name of the event as String
     * @param eventInfo properties in key/value pair
     * @param eventTime eventTime as Date
     */
    private func logEventWithTime(call: FlutterMethodCall, result: @escaping FlutterResult){
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            let dateTime = arguments["time"] as? Date
            BlotoutAnalytics.sharedInstance()?.logEvent(eventName!, withInformation: properties, happendAt: dateTime)
        }
    }
    
    /*
     * @param eventName name of the event as String
     * @param eventInfo properties in key/value pair
     */
    private func logUserRetentionEvent(call: FlutterMethodCall, result: @escaping FlutterResult){
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            
            BlotoutAnalytics.sharedInstance()?.logUserRetentionEvent(eventName!, withInformation: properties)
        }
    }
    
    /*
     * @param eventName name of the event as String
     * @param eventInfo properties in key/value pair
     */
    private func logPIIEvent(call: FlutterMethodCall, result: @escaping FlutterResult){
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            let dateTime = arguments["time"] as? Date
            BlotoutAnalytics.sharedInstance()?.logPIIEvent(eventName!, withInformation: properties, happendAt:dateTime)
        }
    }
    
    /*
     * @param eventName name of the event as String
     * @param eventInfo properties in key/value pair
     */
    private func logPHIEvent(call: FlutterMethodCall, result: @escaping FlutterResult){
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            let dateTime = arguments["time"] as? Date
            BlotoutAnalytics.sharedInstance()?.logPHIEvent(eventName!, withInformation: properties, happendAt:dateTime)
        }
    }
    
    /**
     * SDK Endpoint Url must be set before Analytics Engine Initialization, It has to be a domain based IP's are considered invalid.
     * @param endPointUrl
     */
    private func setSDKEndPoint(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let endPoint = arguments["endPoint"] as? String {
                BlotoutAnalytics.sharedInstance()?.sdkEndPointUrl = endPoint
            }
        }
    }
    
    
    private func setSDKEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["sdkEnabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isEnabled = enabled
            }
        }
    }
    
    /*
     * @param networkSyncEnabled default is true, set false to disable the Network call
     */
    
    private func setNetworkSyncEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isNetworkSyncEnabled = enabled
            }
        }
    }
    
    private func setDataCollectionEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isDataCollectionEnabled = enabled
            }
        }
    }
    
    private func setFunnelEventsEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isFunnelEventsEnabled = enabled
            }
        }
    }
    
    private func setSegmentEventsEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isSegmentEventsEnabled = enabled
            }
        }
    }
    
    private func setRetentionEventsEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isRetentionEventsEnabled = enabled
            }
        }
    }
    
    private func setDeveloperEventsEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isDeveloperEventsEnabled = enabled
            }
        }
    }
    
    private func setSystemEventsEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isSystemEventsEnabled = enabled
            }
        }
    }
    
    private func setPayingUser(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isPayingUser = enabled
            }
        }
    }
    
    private func isDeviceCompromised(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isDeviceCompromised())
    }
    
    private func isAppCompromised(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isAppCompromised())
    }
    
    private func isNetworkProxied(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isNetworkProxied())
    }
    
    private func isSimulator(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isDeviceCompromised())
    }
    
    private func isRunningOnVM(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isRunningOnVM())
    }
    
    private func isEnvironmentSecure(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isEnvironmentSecure())
    }
    
}

==> blotoutfluttersdk-0.0.5.tar.gz: ios/Classes/SwiftBlotoutfluttersdkPlugin.swift <==
import Flutter
import UIKit

public class SwiftBlotoutfluttersdkPlugin: NSObject, FlutterPlugin {
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "blotoutfluttersdk", binaryMessenger: registrar.messenger())
        let instance = SwiftBlotoutfluttersdkPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        switch call.method {
        case MethodName.Initialize_SDK.rawValue:
            self.initializeAnalyticsEngine(call: call, result: result)
            break;
        case MethodName.Update_Blotout_SDK.rawValue:
            self.updateAnalyticsEngineTest(call: call, result:result)
            break;
        case MethodName.Start_Timed_Event.rawValue:
            self.startTimedEvent(call: call, result:result)
            break;
        case MethodName.End_Timed_Event.rawValue:
            self.endTimedEvent(call: call, result:result);
            break;
        case MethodName.Log_Event.rawValue:
            self.logEvent(call: call, result:result)
            break;
        case MethodName.Log_Event_With_Time.rawValue:
            self.logEventWithTime(call: call, result:result)
            break;
        case MethodName.Log_PII_Event.rawValue:
            self.logPIIEvent(call: call, result:result)
            break;
        case MethodName.Log_PHI_Event.rawValue:
            self.logPHIEvent(call: call, result:result)
            break;
            case MethodName.Log_User_Retention_Event.rawValue:
            self.logUserRetentionEvent(call: call, result:result)
            break;
        case MethodName.Set_SDK_End_Point_Url.rawValue:
            self.setSDKEndPoint(call: call, result: result)
            break;
        case MethodName.Set_SDK_Enabled.rawValue:
            self.setSDKEnabled(call: call, result: result)
            break;
        case MethodName.Set_Network_Sync_Enabled.rawValue:
            self.setNetworkSyncEnabled(call: call, result: result)
            break;
        case MethodName.Set_Funnel_Events_Enabled.rawValue:
            self.setFunnelEventsEnabled(call: call, result: result)
            break;
        case MethodName.Set_Segment_Events_Enabled.rawValue:
            self.setSegmentEventsEnabled(call: call, result: result)
            break;
        case MethodName.Set_Data_Collection_Enabled.rawValue:
            self.setDataCollectionEnabled(call: call, result: result)
            break;
        case MethodName.Set_System_Events_Enabled.rawValue:
            self.setSystemEventsEnabled(call: call, result: result)
            break;
        case MethodName.Set_Paying_User.rawValue:
            self.setPayingUser(call: call, result: result)
            break;
        case MethodName.Set_Developer_Events_Enabled.rawValue:
            self.setDeveloperEventsEnabled(call: call, result: result)
            break;
        case MethodName.Set_Retention_Events_Enabled.rawValue:
            self.setRetentionEventsEnabled(call: call, result: result)
            break;
            
        case MethodName.IS_Device_Compromised.rawValue:
            self.isDeviceCompromised(call: call, result: result)
            break;
            
        case MethodName.IS_App_Compromised.rawValue:
            self.isAppCompromised(call: call, result: result)
            break;
            
        case MethodName.IS_Simulator.rawValue:
            self.isSimulator(call: call, result: result)
            break;
            
        case MethodName.IS_Environment_Secure.rawValue:
            self.isEnvironmentSecure(call: call, result: result)
            break;
            
        case MethodName.IS_Network_Proxied.rawValue:
            self.isNetworkProxied(call: call, result: result)
            break;
            
        case MethodName.IS_Running_On_VM.rawValue:
            self.isRunningOnVM(call: call, result: result)
            break;
            
        default:
            break;
        }
    }
}


extension SwiftBlotoutfluttersdkPlugin {
    
    enum MethodName: String, CaseIterable {
        case Initialize_SDK = "initBlotoutSDK"
        case Update_Blotout_SDK = "updateBlotoutSDK"
        case Start_Timed_Event = "startTimedEvent"
        case End_Timed_Event = "endTimedEvent"
        case Log_Event = "logEvent"
        case Log_Event_With_Time = "logEventWithTime"
        case Log_User_Retention_Event = "logUserRetentionEvent"
        case Log_PII_Event = "logPIIEvent"
        case Log_PHI_Event = "logPHIEvent"
        
        case Set_SDK_End_Point_Url = "setSDKEndPointUrl"
        case Set_SDK_Enabled = "setSDKEnabled"
        case Set_Network_Sync_Enabled = "setNetworkSyncEnabled"
        case Set_Data_Collection_Enabled = "setDataCollectionEnabled"
        case Set_Funnel_Events_Enabled = "setFunnelEventsEnabled"
        case Set_Segment_Events_Enabled = "setSegmentEventsEnabled"
        case Set_System_Events_Enabled = "setSystemEventsEnabled"
        case Set_Developer_Events_Enabled = "setDeveloperEventsEnabled"
        case Set_Paying_User = "setPayingUser"
        case Set_Retention_Events_Enabled = "setRetentionEventsEnabled"
        
        case IS_Device_Compromised = "isDeviceCompromised"
        case IS_App_Compromised = "isAppCompromised"
        case IS_Network_Proxied = "isNetworkProxied"
        case IS_Simulator = "isSimulator"
        case IS_Running_On_VM = "isRunningOnVM"
        case IS_Environment_Secure = "isEnvironmentSecure"
    }
}

extension SwiftBlotoutfluttersdkPlugin {
    
    private func initializeAnalyticsEngine(call: FlutterMethodCall, result: @escaping FlutterResult){
        
        if let arguments = call.arguments as? [String:Any] {
            
            if let token = arguments["prodKey"] as? String {
                let testKey = arguments["testKey"] as? String
                let isProd = arguments["isProd"] as? Bool
                BlotoutAnalytics.sharedInstance()?.initializeAnalyticsEngine(usingTest: testKey!, andProduction: token, inProductionMode: isProd!, withCompletionHandler: { (success, error) in
                    if(success) {
                        return result(true)
                    } else {
                        return result(false)
                    }
                })
            }
        }
    }
    
    
    /*
     * @param blotoutTestKey stage key as String
     * @param blotoutProductionKey production key as String
     */
    private func updateAnalyticsEngineTest(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let token = arguments["prodKey"] as? String {
                BlotoutAnalytics.sharedInstance()?.updateEngineTest(token, andProduction: token);
            }
        }
        
    }
    
    /*
     * @param eventName name of the event
     * @param startEventInfo properties in key/value pair
     */
    private func startTimedEvent(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            
            BlotoutAnalytics.sharedInstance()?.startTimedEvent(eventName!, withInformation: properties)
        }
    }
    
    /*
     * @param eventName name of the event
     * @param endEventInfo properties in key/value pair
     */
    private func endTimedEvent(call: FlutterMethodCall, result: @escaping FlutterResult){
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            
            BlotoutAnalytics.sharedInstance()?.endTimedEvent(eventName!, withInformation: properties)
        }
    }
    
    /*
     * @param eventName name of the event
     * @param eventInfo properties in key/value pair
     */
    private func logEvent(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            
            BlotoutAnalytics.sharedInstance()?.logEvent(eventName!, withInformation: properties)
        }
    }
    
    /*
     * @param eventName name of the event as String
     * @param eventInfo properties in key/value pair
     * @param eventTime eventTime as Date
     */
    private func logEventWithTime(call: FlutterMethodCall, result: @escaping FlutterResult){
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            let dateTime = arguments["time"] as? Date
            BlotoutAnalytics.sharedInstance()?.logEvent(eventName!, withInformation: properties, happendAt: dateTime)
        }
    }
    
    /*
     * @param eventName name of the event as String
     * @param eventInfo properties in key/value pair
     */
    private func logUserRetentionEvent(call: FlutterMethodCall, result: @escaping FlutterResult){
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            
            BlotoutAnalytics.sharedInstance()?.logUserRetentionEvent(eventName!, withInformation: properties)
        }
    }
    
    /*
     * @param eventName name of the event as String
     * @param eventInfo properties in key/value pair
     */
    private func logPIIEvent(call: FlutterMethodCall, result: @escaping FlutterResult){
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            let dateTime = arguments["time"] as? Date
            BlotoutAnalytics.sharedInstance()?.logPIIEvent(eventName!, withInformation: properties, happendAt:dateTime)
        }
    }
    
    /*
     * @param eventName name of the event as String
     * @param eventInfo properties in key/value pair
     */
    private func logPHIEvent(call: FlutterMethodCall, result: @escaping FlutterResult){
        if let arguments = call.arguments as? [String:Any] {
            let eventName = arguments["eventName"] as? String
            let properties = arguments["properties"] as? [String: Any]
            let dateTime = arguments["time"] as? Date
            BlotoutAnalytics.sharedInstance()?.logPHIEvent(eventName!, withInformation: properties, happendAt:dateTime)
        }
    }
    
    /**
     * SDK Endpoint Url must be set before Analytics Engine Initialization, It has to be a domain based IP's are considered invalid.
     * @param endPointUrl
     */
    private func setSDKEndPoint(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let endPoint = arguments["endPoint"] as? String {
                BlotoutAnalytics.sharedInstance()?.sdkEndPointUrl = endPoint
            }
        }
    }
    
    
    private func setSDKEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["sdkEnabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isEnabled = enabled
            }
        }
    }
    
    /*
     * @param networkSyncEnabled default is true, set false to disable the Network call
     */
    
    private func setNetworkSyncEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isNetworkSyncEnabled = enabled
            }
        }
    }
    
    private func setDataCollectionEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isDataCollectionEnabled = enabled
            }
        }
    }
    
    private func setFunnelEventsEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isFunnelEventsEnabled = enabled
            }
        }
    }
    
    private func setSegmentEventsEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isSegmentEventsEnabled = enabled
            }
        }
    }
    
    private func setRetentionEventsEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isRetentionEventsEnabled = enabled
            }
        }
    }
    
    private func setDeveloperEventsEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isDeveloperEventsEnabled = enabled
            }
        }
    }
    
    private func setSystemEventsEnabled(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isSystemEventsEnabled = enabled
            }
        }
    }
    
    private func setPayingUser(call: FlutterMethodCall, result: @escaping FlutterResult) {
        if let arguments = call.arguments as? [String:Any] {
            if let enabled = arguments["enabled"] as? Bool {
                BlotoutAnalytics.sharedInstance()?.isPayingUser = enabled
            }
        }
    }
    
    private func isDeviceCompromised(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isDeviceCompromised())
    }
    
    private func isAppCompromised(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isAppCompromised())
    }
    
    private func isNetworkProxied(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isNetworkProxied())
    }
    
    private func isSimulator(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isDeviceCompromised())
    }
    
    private func isRunningOnVM(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isRunningOnVM())
    }
    
    private func isEnvironmentSecure(call: FlutterMethodCall, result: @escaping FlutterResult) {
        return result(BlotoutAnalytics.sharedInstance()?.isEnvironmentSecure())
    }
    
}
